# chaquopy-stubs-android

Python type stubs for Android API Level 36, generated with [chaquopy-stubgen](https://github.com/timrid/chaquopy-stubgen) `0.3.3`.

> **⚠️ Disclaimer:** This is **not** an official tool of the [Chaquopy](https://github.com/chaquo/chaquopy) project. It is an independent, community-maintained project.

## Usage

These are stub-only packages ([PEP 561](https://peps.python.org/pep-0561/)). Install them alongside your project to get type checking support for `Android API Level 36` when using [Chaquopy](https://github.com/chaquo/chaquopy).

```bash
pip install chaquopy-stubs-android~=36.0
```